@@ -36,14 +36,14 @@ GribReader::GribReader()
 	ymax = -1e300;
 }
 //-------------------------------------------------------------------------------
-void GribReader::openFile (const std::string &fname, int nbrecs)
+void GribReader::openFile (const QString &fname, int nbrecs)
 {
 	continueDownload = true;
 	setAllDataCenterModel.clear();
 	setAllDates.clear ();
 	setAllDataCode.clear ();
 	
-    if (!fname.empty()) {
+    if (!fname.isEmpty()) {
         openFilePriv (fname, nbrecs);
     }
     else {
@@ -157,6 +157,9 @@ void GribReader::readAllGribRecords (int nbrecs)
 			|| ( (rec->getDataType()==GRB_TMIN || rec->getDataType()==GRB_TMAX)
 					&& rec->getLevelType()==LV_ABOV_GND && rec->getLevelValue()==2)
 			//-----------------------------------------
+			|| ( rec->getDataType()==GRB_DEWPOINT
+					&& rec->getLevelType()==LV_ABOV_GND && rec->getLevelValue()==2)
+			//-----------------------------------------
 			|| (rec->getDataType()==GRB_TEMP
 					&& rec->getLevelType()==LV_ABOV_GND && rec->getLevelValue()==2)
 			|| (rec->getDataType()==GRB_TEMP
@@ -189,7 +192,8 @@ void GribReader::readAllGribRecords (int nbrecs)
 			//-----------------------------------------
 			// Current
 			//-----------------------------------------
-			|| ( (rec->getDataType()==GRB_CUR_VX || rec->getDataType()==GRB_CUR_VY)
+			|| ( (rec->getDataType()==GRB_CUR_VX || rec->getDataType()==GRB_CUR_VY
+			      || rec->getDataType()==GRB_CUR_DIR || rec->getDataType()==GRB_CUR_SPEED)
                     /*&& rec->getLevelType()==LV_GND_SURF
                     && rec->getLevelValue()==0*/ )
 			//-----------------------------------------
@@ -335,6 +339,8 @@ void GribReader::readAllGribRecords (int nbrecs)
             //-----------------------------------------
 			|| (rec->getLevelType()==LV_GND_SURF
 				&& (   rec->getDataType()==GRB_WAV_SIG_HT
+					|| rec->getDataType()==GRB_WAV_DIR
+					|| rec->getDataType()==GRB_WAV_PER
 					|| rec->getDataType()==GRB_WAV_WND_DIR
 					|| rec->getDataType()==GRB_WAV_WND_HT
 					|| rec->getDataType()==GRB_WAV_WND_PER
@@ -358,10 +364,11 @@ void GribReader::readAllGribRecords (int nbrecs)
 			}
 			else {
 				fprintf(stderr,
-					"GribReader: id=%d unknown data: key=0x%lx  idCenter==%d && idModel==%d && idGrid==%d\n",
+					"GribReader: id=%d unknown data: key=0x%lx  idCenter==%d && idModel==%d && idGrid==%d dataType==%d\n",
 					rec->getId(),
 					rec->getKey(),
-					rec->getIdCenter(), rec->getIdModel(), rec->getIdGrid()
+					rec->getIdCenter(), rec->getIdModel(), rec->getIdGrid(),
+					rec->getDataType()
 					);
 			}
 		}
@@ -482,7 +489,7 @@ void  GribReader::copyFirstCumulativeRecord (DataCode dtc)
 		rec = getFirstGribRecord (dtc);
 		if (rec != nullptr)
 		{
-			GribRecord *r2 = new GribRecord (*rec);
+			GribRecord *r2 = new GribRecord (*rec, false);
 			r2->setRecordCurrentDate (dateref);    // 1er enregistrement factice
 			storeRecordInMap (r2);
 		}
@@ -508,7 +515,7 @@ void  GribReader::copyMissingWaveRecords (DataCode dtc)
 			if (rec2) {
 				if (!rec2->isDuplicated()) {
 					// create a copied record from date2
-					GribRecord *r2 = new GribRecord (*rec2);
+					GribRecord *r2 = new GribRecord (*rec2, false);
 					r2->setRecordCurrentDate (date);
 					storeRecordInMap (r2);
 				}
@@ -521,6 +528,8 @@ void  GribReader::copyMissingWaveRecords (DataCode dtc)
 void  GribReader::copyMissingWaveRecords ()
 {
 	copyMissingWaveRecords (DataCode(GRB_WAV_SIG_HT,LV_GND_SURF,0));
+	copyMissingWaveRecords (DataCode(GRB_WAV_DIR,LV_GND_SURF,0));
+	copyMissingWaveRecords (DataCode(GRB_WAV_PER,LV_GND_SURF,0));
 	copyMissingWaveRecords (DataCode(GRB_WAV_WND_DIR,LV_GND_SURF,0));
 	copyMissingWaveRecords (DataCode(GRB_WAV_WND_HT,LV_GND_SURF,0));
 	copyMissingWaveRecords (DataCode(GRB_WAV_WND_PER,LV_GND_SURF,0));
@@ -933,7 +942,7 @@ void GribReader::createListDates()
 //-------------------------------------------------------------------------------
 // Lecture complète d'un fichier GRIB
 //-------------------------------------------------------------------------------
-void GribReader::openFilePriv (const std::string& fname, int nbrecs)
+void GribReader::openFilePriv (const QString& fname, int nbrecs)
 {
 //     debug("Open file: %s", fname.c_str());
     fileName = fname;
@@ -942,9 +951,9 @@ void GribReader::openFilePriv (const std::string& fname, int nbrecs)
     //--------------------------------------------------------
     // Ouverture du fichier
     //--------------------------------------------------------
-    file = zu_open (fname.c_str(), "rb", ZU_COMPRESS_AUTO);
+    file = zu_open (qPrintable(fname), "rb", ZU_COMPRESS_AUTO);
     if (file == nullptr) {
-        erreur("Can't open file: %s", fname.c_str());
+        erreur("Can't open file: %s", qPrintable(fname));
         return;
     }
     
