@@ -365,6 +365,7 @@ MenuBar::MenuBar (QWidget *parent, bool mbe)
 		acView_WhiteCapProb = addActionCheck (menuSeaState, tr("Whitecap probability"), "", "");
 		menuWavesArrows = new QMenu (tr("Waves arrows"));
 			acView_WavesArrows_none = addActionCheck (menuWavesArrows, tr("None"), "", "");
+			acView_WavesArrows_sig = addActionCheck (menuWavesArrows, tr("Combined wave and swell"), "", "");
 			acView_WavesArrows_max = addActionCheck (menuWavesArrows, tr("Maximum wave"), "", "");
 			acView_WavesArrows_swell = addActionCheck (menuWavesArrows, tr("Swell"), "", "");
 			acView_WavesArrows_wind = addActionCheck (menuWavesArrows, tr("Wind wave"), "", "");
@@ -384,6 +385,7 @@ MenuBar::MenuBar (QWidget *parent, bool mbe)
 		// Waves arrows type
 		acView_GroupWavesArrows = new QActionGroup (menuWavesArrows);
 			acView_GroupWavesArrows->addAction (acView_WavesArrows_none);
+			acView_GroupWavesArrows->addAction (acView_WavesArrows_sig);
 			acView_GroupWavesArrows->addAction (acView_WavesArrows_max);
 			acView_GroupWavesArrows->addAction (acView_WavesArrows_swell);
 			acView_GroupWavesArrows->addAction (acView_WavesArrows_wind);
@@ -434,7 +436,7 @@ MenuBar::MenuBar (QWidget *parent, bool mbe)
             acRunMaintenanceTool = addAction (menuHelp, tr("Run XyGrib Maintenance Tool"),"",
                                           tr("To add, update or remove XyGrib components"),"");
 
-        acHelp_AProposQT = addAction (menuHelp, tr("About QT"),"","","");
+        acHelp_AProposQT = addAction (menuHelp, tr("About Qt"),"","","");
 
     //======================================================================
     addMenu (menuFile);
@@ -456,10 +458,7 @@ MenuBar::MenuBar (QWidget *parent, bool mbe)
     cbDatesGrib = new QComboBox ();
     cbDatesGrib->setSizeAdjustPolicy (QComboBox::AdjustToContents);
     cbDatesGrib->addItem("-------------------------");
-
-	cbDatesGrib->setEnabled (false);
-	acDatesGrib_prev->setEnabled (true);
-	acDatesGrib_next->setEnabled (true);
+    updateDateSelector();
 
     cbModelRect = new QComboBox ();
     cbModelRect->setSizeAdjustPolicy (QComboBox::AdjustToContents);
@@ -654,6 +653,7 @@ void MenuBar::setCitiesNamesLevel (int level) {
 void MenuBar::setWaveArrowsType (int type) {
     switch (type) {
         case GRB_TYPE_NOT_DEFINED: acView_WavesArrows_none->setChecked(true); break;
+        case GRB_PRV_WAV_SIG:  acView_WavesArrows_sig->setChecked(true); break;
         case GRB_PRV_WAV_MAX:  acView_WavesArrows_max->setChecked(true); break;
         case GRB_PRV_WAV_SWL:  acView_WavesArrows_swell->setChecked(true); break;
         case GRB_PRV_WAV_WND:  acView_WavesArrows_wind->setChecked(true); break;
@@ -668,7 +668,7 @@ void MenuBar::updateListeDates(std::set<time_t> *setDates, time_t currentDate)
 {
     listGribDates.clear();
     // Construit un vector à partir du set (plus pratique)
-    for (long setDate : *setDates) {
+    if (setDates) for (long setDate : *setDates) {
         listGribDates.push_back(setDate);
     }
 
@@ -676,30 +676,47 @@ void MenuBar::updateListeDates(std::set<time_t> *setDates, time_t currentDate)
     while (cbDatesGrib->count() > 0) {
         cbDatesGrib->removeItem(0);
     }
+    auto nbe_dates = listGribDates.size();
     for (long tps : listGribDates) {
         QString str = Util::formatDateTimeLong(tps);
         //printf("%s\n", qPrintable(str));
         cbDatesGrib->addItem(str);
     }
-	
-	updateCurrentDate (currentDate);
+    if ( nbe_dates > 1) {
+        updateDateSelector( );
+        updateCurrentDate (currentDate);
+        return;
+    }
+    if (nbe_dates == 0) {
+        cbDatesGrib->addItem("-------------------------");
+    }
+    updateDateSelector();
 }
+
+void MenuBar::updateDateSelector()
+{
+    bool enable = listGribDates.size() > 1;
+    acDatesGrib_prev->setEnabled (enable);
+	acDatesGrib_next->setEnabled (enable);
+	cbDatesGrib->setEnabled (enable);
+}
+
 //------------------------------------------------------------
 time_t  MenuBar::getDateGribById(int id)
 {
     if (listGribDates.size() > (uint)id)
         return listGribDates[id];
-    else
-        return (time_t)0;
+
+    return (time_t)0;
 }
 //------------------------------------------------------------
 void MenuBar::updateCurrentDate (time_t currentDate)
 {
-	acDatesGrib_prev->setEnabled (true);
-	acDatesGrib_next->setEnabled (true);
 	QString strCurrentDate = Util::formatDateTimeLong (currentDate);
 	int id = cbDatesGrib->findText (strCurrentDate);
-	if (id >= 0) {
+	if (id >= 0 && listGribDates.size() > 1) {
+	    acDatesGrib_prev->setEnabled (true);
+	    acDatesGrib_next->setEnabled (true);
 		cbDatesGrib->setCurrentIndex (id);
 		if (id == 0) {
 			acDatesGrib_prev->setEnabled (false);
